# -*- coding: utf-8 -*-
import sys
import requests
from requests.compat import quote, urlparse, urljoin
from bs4 import BeautifulSoup

def htmlparser(url):
    r = requests.get(url)
    if not r.ok:
        raise requests.HTTPError
    r.encoding = 'utf-8-sig'
    content = r.text
    if sys.version_info >= (2, 7, 3) and sys.version_info < (3, 0):
        return BeautifulSoup(content, 'html.parser')
    if sys.version_info >= (3, 2) and sys.version_info < (4, 0):
        return BeautifulSoup(content, 'html.parser')
    return BeautifulSoup(content, 'html5lib')


def category(cat, page=1):
    url = 'http://www.haitum.com/%s/page/%d' % (cat, page)
    try:
        soup = htmlparser(url)
    except:
        return {'code': 'haitum 200'}
    items = []
    try:
        for e1 in soup.find('ul', {'class': 'new-list'}).find_all('li'):
            e2 = e1.find('a')
            if not e2:
                continue
            if 'href' not in e2.attrs:
                continue
            title = e2.find('div').find('p').getText()
            e3 = e2.find('span')
            if e3:
                title += ' ' + e3.getText()
            items.append({'title': title, 'url': urljoin(url, e2.attrs['href'])})
    except:
        return {'code': 'haitum 201'}
    items.append({'title': 'Next Page', 'category': cat, 'page': page + 1})
    return {'item': items}


def movie(url, index=-1):
    items = []
    if index == -1:
        try:
            soup = htmlparser(url)
        except:
            return {'code': 'haitum 101'}
        try:
            i = -1
            for e1 in soup.find('ul', {'class': 'nav-tabs'}).find_all('li'):
                i += 1
                e2 = e1.find('a')
                if not e2:
                    continue
                title = e2.getText()
                if 'title' in e2.attrs:
                    title += ' ' + e2.attrs['title']
                items.append({'title': title, 'url': url, 'index': i})
        except:
            return {'code': 'haitum 102'}
        return {'item': items}
    o = urlparse(url)
    p = o.path.split('/')
    assert p[2]
    if p[2][-5:] != '.html':
        return {'code': 'haitum 100'}
    p[2] = p[2][:-5]
    data = {
        'order': 'getTargetRsBoxData',
        'ids': p[2],
        'type': 2,
        'index': index
    }
    try:
        r = requests.post('http://www.haitum.com/common/api_getTargetRsBoxData.php', data=data)
    except:
        return {'code': 'haitum 110'}
    r.encoding = 'utf-8-sig'
    try:
        data = r.json()
    except:
        return {'code': 'haitum 111'}
    try:
        for e in data['data']['episodes']:
            items.append({'title': e['title'], 'url': e['url']})
    except:
        return {'code': 'haitum 112'}
    return {'item': items}
    # o = urlparse(url)
    # p = o.path.split('/')
    # assert p[2]
    # if p[2][-5:] != '.html':
    #     return {'code': 'haitum 100'}
    # p[2] = p[2][:-5]
    # p[2] = p[2].split('-')
    # if len(p[2]) != 2:
    #     return {'code': 'haitum 101'}
    # data = {
    #     'order': 'getNewHost',
    #     'aid': '',
    #     'sid': p[2][0],
    #     'mid': p[2][1],
    #     'isstatic': 1,
    #     'target': 'movieDetails',
    #     'rp0': 1,
    #     'rp1': 1,
    #     'isBackServerRsData': 1
    # }
    # try:
    #     r = requests.post('http://www.haitum.com/common/api_getNewHost.php', data=data)
    # except:
    #     return {'code': 'haitum 102'}
    # r.encoding = 'utf-8-sig'
    # try:
    #     data = r.json()
    # except:
    #     return {'code': 'haitum 103'}
    # items = []
    # try:
    #     for e in data['data']['resource']['episodes']:
    #         items.append({'title': e['title'], 'url': e['url']})
    # except:
    #     return {'code': 'haitum 104'}
    # return {'item': items}


def search(s):
    url = 'http://www.haitum.com/search/%s' % quote(s)
    try:
        soup = htmlparser(url)
    except:
        return {'code': 'haitum 301'}
    items = []
    try:
        for e1 in soup.find('ul', {'class': 'search-list'}).find_all('li'):
            e2 = e1.find('h5')
            if not e2:
                continue
            e3 = e2.find('a')
            if not e3:
                continue
            if 'href' not in e3.attrs:
                continue
            items.append({'title': e3.getText(), 'url': urljoin(url, e3.attrs['href'])})
    except:
        return {'code': 'haitum 302'}
    return {'item': items}
